pub struct PreservedSparseTrie { /* private fields */ }Expand description
A preserved sparse trie that can be reused across payload validations.
Implementations
Sourceimpl PreservedSparseTrie
impl PreservedSparseTrie
Sourcepub const fn anchored(
trie: SparseTrie,
state_root: B256,
anchor_hash: B256,
) -> Self
pub const fn anchored( trie: SparseTrie, state_root: B256, anchor_hash: B256, ) -> Self
Creates a new anchored preserved trie.
The state_root is the computed state root from the trie. The anchor_hash is the parent
block hash of the earliest overlay state covered by the trie.
Sourcepub fn pending(
state_root: B256,
anchor_hash: B256,
) -> (Self, PreservedSparseTrieCompleter)
pub fn pending( state_root: B256, anchor_hash: B256, ) -> (Self, PreservedSparseTrieCompleter)
Creates a pending preserved trie and a completer that will publish the trie later.
Sourcepub const fn state_root(&self) -> B256
pub const fn state_root(&self) -> B256
Returns the state root this trie is anchored to.
Sourcepub const fn anchor_hash(&self) -> B256
pub const fn anchor_hash(&self) -> B256
Returns the parent block hash of the earliest overlay state covered by this trie.
Sourcepub fn into_trie_for(
self,
parent_state_root: B256,
) -> Result<Option<SparseTrie>, PreservedSparseTrieError>
pub fn into_trie_for( self, parent_state_root: B256, ) -> Result<Option<SparseTrie>, PreservedSparseTrieError>
Consumes self and returns the trie if it can be reused for the parent state root.
If the parent state root does not match the preserved trie’s state root, this drops the trie
and returns None so the caller can create a fresh sparse trie.