SparseTrie

Type Alias SparseTrie 

pub type SparseTrie = SparseStateTrie;
Type alias for the sparse trie type used in preservation.

Aliased Type

pub struct SparseTrie { /* private fields */ }

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 336 bytes